package org.rcisoft.business.memGoldCoinFlow.controller;


/*固定导入*/
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.Operation;
import org.rcisoft.business.memGoldCoinFlow.entity.MemGoldCoinFlow;
import org.rcisoft.business.memGoldCoinFlow.service.MemGoldCoinFlowService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.model.CyGridModel;
import jakarta.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import java.util.List;

/**
* Created by cy on 2025年2月7日 上午10:11:22.
*/
@RestController
@RequestMapping("/memGoldCoinFlow")
public class MemGoldCoinFlowController extends CyPaginationController<MemGoldCoinFlow> {


    @Autowired
    private MemGoldCoinFlowService memGoldCoinFlowServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('sys:goldCoinFlow:add')")
    @CyOpeLogAnno(title = "system-金币流水表管理-新增金币流水表", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加金币流水表", description="添加金币流水表")
    @PostMapping(value = "/add")
    public CyResult add(@Valid MemGoldCoinFlow memGoldCoinFlow, BindingResult bindingResult) {
        CyPersistModel data = memGoldCoinFlowServiceImpl.persist(memGoldCoinFlow);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        memGoldCoinFlow);
    }

    @PreAuthorize("@cyPerm.hasPerm('sys:goldCoinFlow:delete')")
    @CyOpeLogAnno(title = "system-金币流水表管理-删除金币流水表", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="逻辑删除金币流水表", description="逻辑删除金币流水表")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,MemGoldCoinFlow memGoldCoinFlow) {
        memGoldCoinFlow.setBusinessId(businessId);
        CyPersistModel data = memGoldCoinFlowServiceImpl.removeLogical(memGoldCoinFlow);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }
    @PreAuthorize("@cyPerm.hasPerm('sys:goldCoinFlow:delete')")
    @CyOpeLogAnno(title = "system-金币流水表管理-删除金币流水表", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="删除金币流水表", description="删除金币流水表")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,MemGoldCoinFlow memGoldCoinFlow) {
        memGoldCoinFlow.setBusinessId(businessId);
        CyPersistModel data = memGoldCoinFlowServiceImpl.remove(memGoldCoinFlow);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('sys:goldCoinFlow:update')")
    @CyOpeLogAnno(title = "system-金币流水表管理-修改金币流水表", businessType = CyLogTypeEnum.UPDATE)
    @Operation(summary="修改金币流水表", description="修改金币流水表")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = false,  schema = @Schema(type = "string"))})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid MemGoldCoinFlow memGoldCoinFlow, BindingResult bindingResult) {
        memGoldCoinFlow.setBusinessId(businessId);
        CyPersistModel data = memGoldCoinFlowServiceImpl.merge(memGoldCoinFlow);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        memGoldCoinFlow);
    }

    @PreAuthorize("@cyPerm.hasPerm('sys:goldCoinFlow:query')")
    @CyOpeLogAnno(title = "system-金币流水表管理-查询金币流水表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询单一金币流水表", description="查询单一金币流水表")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        memGoldCoinFlowServiceImpl.findById(businessId));
    }

    @PreAuthorize("@cyPerm.hasPerm('sys:goldCoinFlow:list')")
    @CyOpeLogAnno(title = "system-金币流水表管理-查询金币流水表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询金币流水表集合", description="查询金币流水表集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(MemGoldCoinFlow memGoldCoinFlow) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            memGoldCoinFlowServiceImpl.findAll(memGoldCoinFlow));
    }

    @PreAuthorize("@cyPerm.hasPerm('sys:goldCoinFlow:list')")
    @CyOpeLogAnno(title = "system-金币流水表管理-查询金币流水表", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询金币流水表集合", description="分页查询金币流水表集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(MemGoldCoinFlow memGoldCoinFlow) {
        memGoldCoinFlowServiceImpl.findAllByPagination(getPaginationUtility(), memGoldCoinFlow);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-金币流水表管理-查询金币流水表", businessType = CyLogTypeEnum.EXPORT)
    @Operation(summary = "导出金币流水表信息", description = "导出金币流水表信息")
    @GetMapping(value = "/export")
    public void outMemGoldCoinFlow(HttpServletResponse response,MemGoldCoinFlow memGoldCoinFlow,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="金币流水表信息.xls";break;
            case "1": excelName="金币流水表信息.xlsx";break;
            case "2": excelName="金币流水表信息.csv";break;
        }
        List<MemGoldCoinFlow> memGoldCoinFlowList = memGoldCoinFlowServiceImpl.export(memGoldCoinFlow);
        CyEpExcelUtil.exportExcel(memGoldCoinFlowList, "金币流水表信息", "金币流水表信息", MemGoldCoinFlow.class, excelName, response);
    }
}
